'\" t
.\"
.\" To properly format this file, you must use the -man troff macros and tbl
.\"
.\$Id: qverify.man,v 1.1 1999/05/27 20:21:23 doug Exp $ 
.if n .na
.TH QVERIFY 1 "24 May 1999" BDSN
.SH NAME
qverify - Verify contents and consistency of single channel Quanterra or MiniSEED data file.
.SH SYNOPSIS
.B qverify
[\fB-n\fR]
[\fB-f\ \fIdate\fR]
[\fB-t\ \fIdate\fR]
[\fB-s\ \fItime_span\fR]
.if n .ti +5
[\fB-S\ \fIstation\fR]
[\fB-C\ \fIchannel\fR]
[\fB-N\ \fInetwork\fR]
.if n .ti +5
[\fB-L\ \fIlocation\fR]
.if t .ti +.5in
[\fB-b\ \fIblksize\fR]
[\fB-V\ \fIverify_pattern\fR]
.if n .ti +5
[\fB-I\ \fIinput_data_format\fR]
[\fB-g\ \fItolerance\fR]
[\fB-G\ \fItolerance\fR]
.if n .ti +5
.if t .ti +.5in
[\fB-D\ j\ |\ m\fR]
[\fB-i\ time\fR]
[\fB-i\ d0\fR]
[\fB-i\ no_d0\fR]
[\fB-i\ V\fR]
.if n .ti +5
[\fB-v\fR]
[\fB-d\ \fInum\fR]
[\fB-h\fR]
\fIinput_file\fR
.br
.SH DESCRIPTION
The program
.B qverify
is a version of the 
.B qmerge 
program that can verify the contents and internal consistency of a MiniSEED
data file.  It can perform the following operations:
.HP
Verify header information from each data record in the file (SEED station,
network, channel, and location) against information derived from the filename
or from explicit command line arguments.
.HP
Verify the MiniSEED blocksize of each data record in the file.
.HP
Verify the data format type of each MiniSEED record (eg STEIM1, STEIM2, INT_16,
INT_32, INT_24) in the file.
.HP
Verify the internal consistency of any STEIM compressed data in each data
record and check for an incorrectly constructed data stream by ensuring
that all contiguous data record stores in STEIM compressed format share the
same compression history.
.HP
Check to ensure that there are no duplicate data records within the file, and
that data records are stored in increasing time order.
.B Qmerge 
will often silently skip over duplicate data records.
.HP
Verify the timespan contents of the file against a timespan derived from the
filename or against a timespan that is explicitly specified on the command line.
.HP
Verify that records within the file are in increasing time order.
.RE

The input file can contain a single channel of either MiniSEED or SEED data records.
The blocksize of each record can be any valid MiniSEED blocksize from 512-byte to
8K-bytes.  The data encoding format can be either STEIM1, STEIM2, INT_16,
INT_24, or INT_32 compression format as described in the FDSN SEED manual.  If
the file consists of SEED data records (eg pre-MiniSEED SEED data records),
all records in the file must have the same blocksize and data format.

.B Qverify
will only operate on files that contain data from a single data stream
(station, network, channel, and location).  If files contain data from
multiple stream, they must first be de-multiplexed into separate
files using the program
.B sdrsplit .

Qverify can use either a default or user-supplied pattern string which it
matches to the actual data filename in order to determine the assumed channel
information (station, network, channel, location) and date (eg year, day of
year).  Details on the pattern string are described later in this document.
You may override the default pattern string using an environment variable
or a command line option.
You may also specify the channel information explicitly on the command line,
or you may choose to use no pattern string and explicitly specify all
verification options on the command line.

.SH OPTIONS
.fi
.TP
\fB-n\fR
specifies that no output files should be created.  
.B qverify
never creates an output data file. This option is preserved
only for compatibility with 
.B qmerge.
.TP
\fB-f \fIdate\fR
.br
specifies a beginning (from) time window for data in the file.
If any data is found before this time it will be flagged as an error.
.TP  
\fB-t \fIdate\fR
.br
specifies an end (to) time window for data in the file.  If any data if found
at or after this time it will be flagged as an error.  
The format for specifying the from and to dates are:
.nf
        yyyy/mm/dd/hh:mm:ss.ffff
        yyyy/mm/dd.hh:mm:ss.ffff
        yyyy/mm/dd,hh:mm:ss.ffff
        yyyy.ddd.hh:mm:ss.ffff
        yyyy.ddd,hh:mm:ss.ffff
        yyyy,ddd,hh:mm:ss.ffff
.fi
where the first format specifies the year, month, day, and time, and the
second format specifies year, julian day, and time.  All trailing components
of the time are optional, and if not specified, are assumed to be 0.
.TP
\fB-s \fItime_span\fR
specifies a time_span (duration) in either seconds, minutes, hours, days, or
months, and is an alternate way of specifying the end of a time interval.
The time_span is an integer followed immediately by the character 
\fBS\fR, \fBM\fR, \fBH\fR, \fBd\fR, or \fBm\fR.  Note that time designators
are upper case, and day designators are lower case.  If no character is
specified, seconds are assumed.  This option is mutually exclusive with the
\fB-t\fR option, and must be used with the \f\B-f\fR option.
.TP
\fB-S \fIstation\fR
specifies the 5-character station code to be verified against each
data record in the file.
This will override the station code derived from the verify pattern.
This station code will be converted to uppercase.
.TP
\fB-C \fIchannel\fR
specifies the 3-character channel code to be verified against each
data record in the file.
This will override the channel code derived from the verify pattern.
This channel code will be converted to uppercase.
.TP
\fB-N \fInetwork\fR
specifies the 2-character network code to be verified against each
data record in the file.
This will override the network code derived from the verify pattern.
This network code will be converted to uppercase.
.TP
\fB-L \fIlocation\fR
specifies the 2-character location code to be verified against each
data record in the file.
This will override the location code derived from the verify pattern.
This location code will be converted to uppercase.
.TP
\fB-b \fIblksize\fR
specifies the blocksize of the input file to be verified.  The blocksize may be any
valid MiniSEED blocksize (ie a power of 2) between 512 and 8K bytes inclusive.
The blocksize may either be specified as
the number of bytes (eg 4096) or as a number of K bytes (eg 4K).
.TP
\fB-V \fIverify_pattern\fR
specifies the verify pattern.  The verify pattern
specifies which components of the filename contain channel
or data information that should be used during the verification 
process.  It is assumed that the filename and pattern each consist
of one or more components (separated by "."), and each
component may contain information used in the verification process.
The pattern can contain the following
special strings which will match the rest of the component:
.TS
l l
l l .
String	Replaced by
_
%S or %s	Station name
%N or %n	Network name
%C or %c	Channel name
%L or %l	Location name
%Y	4 digit year (0000-9999)
%m	2 digit month (01-12)
%d	2 digit day of month (01-31)
%j	3 digit day of year (000-366)
%H	2 digit hour (00-23)
%M	2 digit minute (00-59)
%X or %x	ignore this component
.TE

For example, if the filename was CMB.BK.BHZ.D.1999.101, and you wanted
to verify the station, network, channel, and date of the file, you 
would use the verify pattern "%S.%N.%C.D.%Y.%j".  If any portion of a
date or time is specified, the program will ensure that each record starts
within that time period.

If you only wanted to verify the station and channel of the file, you would
use the verify pattern "%S.%X.%C".  Note that the verify pattern may contain
fewer components than the filename, but that all parts of the pattern must
match components of the filename.  For example, the pattern "%S.%X.%C.Z" would
not match the filename above, because the fourth component of the filename is
"D", whereas the fourth component of the pattern is "Z".  

The default pattern is "%S.%N.%C.D.%Y.%j".
If you want to change the default pattern, you may set the environment
variable 
.B QVERIFY_PATTERN
to contain your own default pattern.
If you want 
.B qverify
to not use ANY verify pattern (eg all verification info will be specified with
command line options), you must either specify an empty verify pattern on the
command line, use the \fB-iV\fR option, or set the environment variable
.B QVERIFY_PATTERN 
to the empty string.
.TP
\fB-I \fIinput_data_format\fR
specifies the input data format to be verified in the input file.
Valid formats are STEIM1, STEIM2, INT_16, INT_24, and INT_32.
.TP
\fB-g \fItolerance\fR
specifies the maximum time difference in ticks (1/10 msec) that is permitted
between adjacent blocks of input data to be merged into a single output block.
If the expected time of the next block differs by less than \fItolerance\fR
number of ticks, the block can be merged with the preceeding block into a
single output block.  The timetag of the composite block will be taken from
the original timetag of the first data point in the block.  If this option is
not used, an appropriate tolerance value based on the sample rate of the data
channel (current .1 * sample interval) will be used.
.TP
\fB-G \fItolerance\fR
specifies the maximum time difference in ticks (1/10 msec) that is permitted
between adjacent blocks of input data to be considered continuous data.  If
the expected time of the next block differs by \fItolerance\fR number of ticks
or more, the data is assumed to be non-continuous between the 2 data blocks.
.B Qverify
will report statistics for each continuous section of data, and will reset
to 1 the initial sequence number of each continuous group of data.  If this
option is not used, and appropriate tolerance value based on the sample rate
of the data channel (current .4 * sample interval) will be used.
.TP
\fB-D\ j\ |\ m\fR
specifies that dates should be displayed in either julian or month format.
The default is julian format.
.TP
\fB-i\ time\fR
specifies that the time span header of a input SEED telemetry file or DRM file
should be ignored, and that the input file must be read in order to decide
whether it contains data for the requested time span.  This option should be
used only when the time span header of the input file contains an invalid timespan.
.TP
\fB-i\ d0\fR
specifies that discrepencies in the initial difference value in the first
block of a file or sequence should be silently fixed.  Otherwise, a warning
will be issued.  Discrepencies in initial difference values can arise during
the merging of 2 files with contiguous data that were independently created with
Steim compression.  If this option is used indiscriminately, valuable warning
messages about invalid data or time tears could be suppressed.
.TP
\fB-i\ no_d0\fR 
specifies that discrepencies in the initial difference value in the first
block of a file or sequence should not be fixed.  Otherwise, a warning will
be issued.  Discrepencies in initial difference values can arise during the
merging of 2 files with contiguous data that were independently created with
Steim compression.  If this option is used indiscriminately, valuable
warning messages about invalid data or time tears could be suppressed.
MiniSEED data from RefTek recorders may have new compression history
at the start of each file.
.TP
\fB-i\ V\fR 
specifies that the any verify pattern (default or explicit) should be ignored.
Any information to be verified must be set on the command line.
.TP
.B -v
verify the internal consistency of all STEIM data frames and data records.
This is the default action, and this option is preserved for compatability
with 
.B qmerge.
.TP
\fB-d \fInum\fR
specifies debugging information should be displayed.  Current debugging
options are:
.nf
.ta 1.0i
	1 = time slews
	2 = time info
	4 = block info
	8 = block headers
	16 = flags
	32 = input stream
	64 = output stream
.fi
.ad
Multiple debugging options can be specified by adding the appropriate values
together.
.TP
.B -h
print out a simple help message with syntax and explaination of the options.
.TP
\fIinput_file\fR
.br
specifies the input data file to be read.
Exactly one data file must be specified.
.SH EXAMPLES
1.  Verify contents and timespan of datafile using default verify pattern.

.nf
qverify /data/archive/bbdata/1998/1998.315/BKS.BK.BHZ.D.1998.315
.fi

2.  Verify contents and timespan of datafile using default verify pattern,
and verify blocksize, and data format using command line arguments.

.nf
qverify -f 4096 -I STEIM1 /data/archive/bbdata/1998/1998.315/BKS.BK.BHZ.D.1998.315
.fi

3.  Verify contents of datafile using explicit info specified on commandline.

.nf
qverify -S CMB -N BK -C LHZ -i V cmb.mseed
.fi

4.  Verify contents and timespan of data using explicit verify pattern.

.nf
qverify -V %s.%c.%Y.%j cmb.bhz.1993.123
.fi

4.  Verify contents and timespan of data using explicit verify pattern
and explicit time span.

.nf
qverify -V %s.%c -f 1993.123 -s 1d cmb.bhz.1993.123
.fi

.SH BUGS

Verification of timespan based on the filename will be done to the smallest
time unit specified in the verify pattern.  If a day is the smallest time unit
specified, then all data records must start in that day.  If an hour is the
smallest time unit specified, then all data records must start within that
hour.

Verification of timespan based on the command line is more flexible, but
must be explicitly specified by the user.  Any data samples that do not fall
within the specified timespan will be flagged as an error.

.SH AUTHOR
Doug Neuhauser, UC Berkeley Seismological Laboratory, doug@seismo.berkeley.edu.
